# CUHKSZ Booking MCP 服务器

一个基于模型上下文协议 (MCP) 的香港中文大学（深圳）场馆预订系统接口服务。

## 📋 目录

- [项目描述](#项目描述)
- [可用工具](#可用工具)
- [安装与部署](#安装与部署)
- [测试说明](#测试说明)
- [项目架构](#项目架构)
- [实现方式与核心逻辑](#实现方式与核心逻辑)
- [故障排除](#故障排除)
- [许可证与免责声明](#许可证与免z声明)

## ✨ 项目描述

一个基于模型上下文协议 (MCP) 的香港中文大学（深圳）场馆预订系统接口服务，该服务使语言模型能够查询场地信息、检查可用时段并执行在线预订。

## 🛠️ 可用工具

- `booking_get_field_info` - 获取指定类型场地的基本信息和当日已有的预订情况。
  - **必要参数**:
    - `field` (string): 场地类型，如 "badminton"。
    - `start_time` (string): 查询预订的开始时间 (格式: `YYYY-MM-DD HH:MM`)。
    - `end_time` (string): 查询预订的结束时间 (格式: `YYYY-MM-DD HH:MM`)。

- `booking_get_available_places` - 查询特定时间段内所有可用的具体场地。
  - **必要参数**:
    - `field` (string): 场地类型，如 "badminton"。
    - `query_start_time` & `query_end_time`: 用于获取当天预订信息的查询范围。
    - `check_start_time` & `check_end_time`: 您希望预订的具体时间段。

- `booking_book` - 预订一个场地。
  - **必要参数**:
    - `field_id` (string): 场地ID, 从 `booking_get_field_info` 获取。
    - `place_id` (string): 具体场所ID, 从 `booking_get_available_places` 获取。
    - `start_time` & `end_time` (string): 预订的起止时间(必填)。
    - `telephone` (string): 联系电话(选填)。
    - `reason` (string): 预订原因(必填)。
    - `details` (string): 预订详情(必填)。

## 🚀 安装与部署

本服务支持 Docker 部署和本地运行两种方式。

### 1. 使用 Docker (推荐)

此方法最简单，推荐用于生产和日常使用。

**a. 环境准备**

- 安装 [Docker](https://www.docker.com/get-started/) 和 [Docker Compose](https://docs.docker.com/compose/install/)。
- 克隆项目:
  ```bash
  git clone https://github.com/BetterAndBetterII/awesome-cuhksz-mcp.git
  cd BOOKING-MCP
  ```

**b. 配置凭证**

在项目根目录 (`BOOKING-MCP/`) 创建一个 `.env` 文件，并填入您的凭证。

```
# .env 文件内容
BOOKING_USERNAME=你的学号
BOOKING_PASSWORD=你的密码
```
**⚠️ 安全提醒**: 请勿将 `.env` 文件提交到版本控制系统。

**c. 构建和启动服务**

```bash
# 构建并以守护进程模式启动容器
docker-compose up --build -d

# 查看实时日志
docker-compose logs -f booking-mcp

# 停止服务
docker-compose down
```
服务启动后，将在 `http://localhost:3001` 上提供 MCP 接口。

### 2. 本地运行 (用于开发)

**a. 环境准备**

克隆项目并进入目录：
```bash
git clone https://github.com/BetterAndBetterII/awesome-cuhksz-mcp.git
cd BOOKING-MCP
```

创建并激活 Python 虚拟环境：
```bash
python3 -m venv .venv
source .venv/bin/activate
```

安装项目依赖（以可编辑模式）：
```bash
pip install -e .
```

**b. 配置凭证**

您可以通过以下两种方式提供凭证（命令行参数优先）：

1.  **（推荐）创建 `.env` 文件**:
    在项目根目录 (`BOOKING-MCP/`) 下创建一个 `.env` 文件。
    ```
    # .env 文件内容
    BOOKING_USERNAME=你的学号
    BOOKING_PASSWORD=你的密码
    ```

2.  **命令行参数**:
    在启动命令中直接提供。

**c. 启动服务**

- 如果您配置了 `.env` 文件：
  ```bash
  # 使用模块名启动 (默认使用 stdio 传输)
  python -m mcp_server_booking
  # 或
  mcp-server-booking
  ```

- 如果您希望使用命令行参数 (默认使用 stdio 传输)：
  ```bash
  python -m mcp_server_booking --username 你的学号 --password 你的密码
  ```
  
> **注意**: `stdio` 模式用于直接的进程间通信，不会监听网络端口。如果需要通过网络（如 `http://localhost:3001`）访问服务，或运行 `test/test.py` 脚本，必须在启动时指定 `sse` 传输模式：
> ```bash
> python -m mcp_server_booking --transport sse
> ```

- 如果您希望使用命令行参数提供凭证并使用 SSE 传输：
  ```bash
  python -m mcp_server_booking --transport sse --username 你的学号 --password 你的密码
  ```

当使用 `sse` 模式启动后，服务将在 `http://localhost:3001` 上提供 MCP 接口。

## ��️ 项目架构

### 核心模块说明

- **`booking.py` (MCP 服务器层)**: 定义 MCP 工具，处理异步请求，管理缓存和登录会话。
- **`booking_system.py` (Booking 交互层)**: 直接与场馆预订系统网站交互，负责登录、数据抓取和表单提交。
- **`__main__.py` (服务入口与凭证管理)**: 处理服务启动、参数配置和凭证校验。

## 🔧 实现方式与核心逻辑

- **登录认证**: 通过向 ADFS 端点发送 POST 请求，直接完成登录认证。
- **缓存管理**: 对查询类工具提供5-10分钟的缓存，以提高响应速度。
- **数据抓取**: 通过请求预订系统的 API (`/eventsV1`) 获取 JSON 数据，或解析 HTML 页面来获取场地信息。

## 🧪 测试说明

项目提供了自动化测试脚本 `test/test.py`。

### 运行测试

```bash
# 确保服务已启动
# 安装测试依赖
pip install -r test/requirements.txt
# 运行测试
python test/test.py
```
脚本支持**安全测试**（不执行预订）和**完整预订测试**两种模式。

## 🔧 故障排除

### 常见问题

- **登录失败**: 检查 `.env` 文件中的 `BOOKING_USERNAME` 和 `BOOKING_PASSWORD` 是否正确。
- **测试连接失败**: 检查 Docker 容器是否正在运行，以及端口 `3001` 是否被占用。
- **启动时报错 "Error: BOOKING_... must be provided"**: 确保已通过 `.env` 文件或命令行参数正确提供了凭证。

## 📄 许可证与免责声明

- **许可证**: 本项目采用 MIT 许可证。
- **免责声明**: 本项目仅供学习和技术研究使用。请遵守学校的相关规定。 